#[repr(u32)]pub enum Colorspace {
Show 15 variants
I420 = 2,
YV12 = 3,
NV12 = 4,
NV21 = 5,
I422 = 6,
YV16 = 7,
NV16 = 8,
YUYV = 9,
UYVY = 10,
V210 = 11,
I444 = 12,
YV24 = 13,
BGR = 14,
BGRA = 15,
RGB = 16,
}Expand description
The colorspace of an image, which details how its colors are represented.
Variants
I420 = 2
A Y plane followed by 2x2 subsampled U and V planes.
YV12 = 3
A Y plane followed by 2x2 subsampled V and U planes.
NV12 = 4
A Y plane followed by a packed 2x2 subsampled UV plane.
NV21 = 5
A Y plane followed by a packed 2x2 subsampled VU plane.
I422 = 6
A Y plane followed by 2x1 subsampled U and V planes.
YV16 = 7
A Y plane followed by 2x1 subsampled V and U planes.
NV16 = 8
A Y plane followed by a packed 2x1 subsampled UV plane.
YUYV = 9
A single plane whose bytes follow the pattern YUYV pattern, which means the U and V parts are 2x1 subsampled.
UYVY = 10
A single plane whose bytes follow the pattern UYVY pattern, which means the U and V parts are 2x1 subsampled.
V210 = 11
A packed 32-bit UYVY plane with 10-bit components, and 2 padding bits.
I444 = 12
A Y plane followed by U and V planes.
YV24 = 13
A Y plane followed by V and U planes.
BGR = 14
A packed 24-bit BGR plane.
BGRA = 15
A packed 32-bit BGR plane, where the latter byte is padding.
RGB = 16
A packed 24-bit RGB plane.