Data

Struct Data 

pub struct Data<'a> { /* private fields */ }
The encoded data, to be used in chunks or in its entirety.

Implementations

Source

impl<'a> Data<'a>

pub fn len(&self) -> usize

The length (in NAL units, not in bytes) of this data sequence.

pub fn unit(&self, i: usize) -> Unit<'a>

The ith unit.

Panics

Panics if i is out-of-bounds. In order to be within the bounds, i must be less than len.

pub fn entirety(&self) -> &[u8]

The entire chunk of data, as one big byte-slice.